@@ -27,23 +27,16 @@ describe 'heat::client' do
 
   end
 
-  context 'on Debian platform' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'Debian',
-      })
-    end
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
 
-    it_configures 'heat client'
+      it_behaves_like 'heat client'
+    end
   end
 
-  context 'on RedHat platform' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'RedHat',
-      })
-    end
-
-    it_configures 'heat client'
-  end
 end
