@@ -10,13 +10,17 @@ describe 'heat::engine' do
       :heat_waitcondition_server_url       => 'http://127.0.0.1:8000/v1/waitcondition',
       :heat_watch_server_url               => 'http://128.0.0.1:8003',
       :engine_life_check_timeout           => '<SERVICE DEFAULT>',
-      :trusts_delegated_roles              => ['heat_stack_owner'],
+      :trusts_delegated_roles              => '<SERVICE DEFAULT>',
       :deferred_auth_method                => '<SERVICE DEFAULT>',
       :default_software_config_transport   => '<SERVICE DEFAULT>',
       :default_deployment_signal_transport => '<SERVICE DEFAULT>',
+      :default_user_data_format            => '<SERVICE DEFAULT>',
       :convergence_engine                  => '<SERVICE DEFAULT>',
+      :reauthentication_auth_method        => '<SERVICE DEFAULT>',
       :environment_dir                     => '<SERVICE DEFAULT>',
       :template_dir                        => '<SERVICE DEFAULT>',
+      :max_nested_stack_depth              => '<SERVICE DEFAULT>',
+      :plugin_dirs                         => '<SERVICE DEFAULT>',
     }
   end
 
@@ -41,8 +45,10 @@ describe 'heat::engine' do
         :deferred_auth_method                => 'trusts',
         :default_software_config_transport   => 'POLL_SERVER_CFN',
         :default_deployment_signal_transport => 'CFN_SIGNAL',
+        :default_user_data_format            => 'HEAT_CFNTOOLS',
         :num_engine_workers                  => '4',
         :convergence_engine                  => false,
+        :reauthentication_auth_method        => 'trusts',
         :environment_dir                     => '/etc/heat/environment.d',
         :template_dir                        => '/etc/heat/templates',
       }
@@ -59,13 +65,13 @@ describe 'heat::engine' do
 
       it { is_expected.to contain_package('heat-engine').with(
         :ensure => 'present',
-        :name   => os_params[:package_name],
+        :name   => platform_params[:package_name],
         :tag    => ['openstack', 'heat-package'],
       ) }
 
       it { is_expected.to contain_service('heat-engine').with(
         :ensure     => (expected_params[:manage_service] && expected_params[:enabled]) ? 'running' : 'stopped',
-        :name       => os_params[:service_name],
+        :name       => platform_params[:service_name],
         :enable     => expected_params[:enabled],
         :hasstatus  => 'true',
         :hasrestart => 'true',
@@ -82,13 +88,16 @@ describe 'heat::engine' do
       it { is_expected.to contain_heat_config('DEFAULT/deferred_auth_method').with_value( expected_params[:deferred_auth_method] ) }
       it { is_expected.to contain_heat_config('DEFAULT/default_software_config_transport').with_value( expected_params[:default_software_config_transport] ) }
       it { is_expected.to contain_heat_config('DEFAULT/default_deployment_signal_transport').with_value( expected_params[:default_deployment_signal_transport] ) }
+      it { is_expected.to contain_heat_config('DEFAULT/default_user_data_format').with_value( expected_params[:default_user_data_format] ) }
       it { is_expected.to contain_heat_config('DEFAULT/instance_connection_is_secure').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('DEFAULT/instance_connection_https_validate_certificates').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('DEFAULT/max_resources_per_stack').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('DEFAULT/num_engine_workers').with_value( expected_params[:num_engine_workers] ) }
       it { is_expected.to contain_heat_config('DEFAULT/convergence_engine').with_value( expected_params[:convergence_engine] ) }
+      it { is_expected.to contain_heat_config('DEFAULT/reauthentication_auth_method').with_value( expected_params[:reauthentication_auth_method] ) }
       it { is_expected.to contain_heat_config('DEFAULT/environment_dir').with_value( expected_params[:environment_dir] ) }
       it { is_expected.to contain_heat_config('DEFAULT/template_dir').with_value( expected_params[:template_dir] ) }
+      it { is_expected.to contain_heat_config('DEFAULT/plugin_dirs').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with disabled service managing' do
@@ -100,13 +109,22 @@ describe 'heat::engine' do
 
       it { is_expected.to contain_service('heat-engine').with(
         :ensure     => nil,
-        :name       => os_params[:service_name],
+        :name       => platform_params[:service_name],
         :enable     => false,
         :hasstatus  => 'true',
         :hasrestart => 'true',
         :tag        => 'heat-service',
       ) }
     end
+
+    context 'with plugin_dirs value set' do
+      before do
+        params.merge!({
+          :plugin_dirs => ['/usr/lib/heat', '/usr/local/lib/heat'] })
+      end
+      it { is_expected.to contain_heat_config('DEFAULT/plugin_dirs').with_value(['/usr/lib/heat,/usr/local/lib/heat']) }
+    end
+
     context 'with wrong auth_encryption_key parameter size' do
       before do
         params.merge!({
@@ -116,35 +134,29 @@ describe 'heat::engine' do
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'Debian',
-      })
-    end
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
 
-    let :os_params do
-      { :package_name => 'heat-engine',
-        :service_name => 'heat-engine'
-      }
-    end
+      let :platform_params do
+        case facts[:osfamily]
+        when 'Debian'
+          { :package_name => 'heat-engine',
+            :service_name => 'heat-engine'
+          }
+        when 'RedHat'
+          { :package_name => 'openstack-heat-engine',
+            :service_name => 'openstack-heat-engine'
+          }
+        end
+      end
 
-    it_configures 'heat-engine'
+      it_behaves_like 'heat-engine'
+    end
   end
 
-  context 'on RedHat platforms' do
-    let :facts do
-      @default_facts.merge({
-        :osfamily => 'RedHat',
-      })
-    end
-
-    let :os_params do
-      { :package_name => 'openstack-heat-engine',
-        :service_name => 'openstack-heat-engine'
-      }
-    end
-
-    it_configures 'heat-engine'
-  end
 end
